Spec-Zone.ru › Qt 5.12

Qt для WinRT

Qt для WinRT позволяет запускать приложения Qt на устройствах, поддерживающих API приложений Магазина Windows. Это охватывает приложения с современным интерфейсом на Windows 10, Windows 10 Mobile и Windows 10 IoT.

Microsoft представила новую парадигму дизайна с современным интерфейсом Windows 8. Центральной частью этого нового подхода является Windows Runtime (WinRT), который поддерживает разработку с использованием различных языков программирования, таких как C++/CX (расширения компонентов), C#, VB.NET или JavaScript. Модуль Qt использует возможности C++. Хотя WinRT поддерживает расширения компонентов внутри, они не используются в Qt, и вам не нужно их использовать. Приложения WinRT выполняются в защищенной среде по соображениям безопасности и поддерживают различные архитектуры, такие как ARM и x86.

Поддерживаемые конфигурации

Поддерживаются следующие конфигурации.

Версия платформы Архитектура Компилятор Среда сборки
Универсальная платформа Windows 10 x86, x86_64, и armv7 MSVC 2017, MSVC 2015 Windows 10 Обновление Creators

Универсальные платформы Windows включают Windows 10, устройства Windows 10 IoT, Xbox One и HoloLens.

Требования

Разработка для Windows Runtime требует хост-системы разработки Microsoft Windows. Минимальная поддерживаемая версия — Windows 10.

В зависимости от целевого устройства вам понадобятся следующие инструменты, предоставленные Microsoft, для установки:

Целевое устройство Среда
Windows 10 Mobile Visual Studio 2015
Рабочий стол Windows 10 Visual Studio 2015
Windows 10 IoT Visual Studio 2015
XBox One Visual Studio 2015

Если вы нацеливаетесь на удаленное устройство, следуйте всем инструкциям Visual Studio для правильной настройки.

Начало работы

Примечания для пользователей рабочего стола

Поскольку приложения WinRT выполняются в защищенной среде, при портировании или написании кроссплатформенных приложений следует учитывать некоторые ограничения:

  • Класс QProcess не реализован (указано определением макроса QT_NO_PROCESS), так как невозможно запускать дочерние процессы.
  • Некоторые пути, возвращаемые QStandardPaths::writableLocation(), могут быть пустыми.
  • Приложение WinRT не может осуществлять обмен через сокеты с другим приложением, выполняющимся на том же хосте (поскольку это нарушит принципы защищенной среды).
  • Приложения выполняются только в полноэкранном режиме (см. QStyleHints). На рабочем столе размер экрана меняется при изменении размера приложения.
  • Переменные среды отсутствуют. Qt эмулирует функциональность, сохраняя значения локально, поэтому функции qputenv() и родственные им продолжают работать. Все известные переменные, влияющие на Qt, можно задать в исходном коде.
  • Приложения WinRT по своей природе являются приложениями с графическим интерфейсом. Это означает, что приложения типа консоли будут иметь созданное внутри окно, которое всегда будет видно.
  • Приложения не должны выходить из программы программно. В частности, вызов exit() до отображения графического интерфейса приводит к сбою.
  • Буфер обмена WinRT локален для приложения; он не может быть получен приложением рабочего стола.

Сборка приложений

Вы можете разрабатывать приложения для WinRT, как и любые другие приложения Qt. Используйте свой любимый редактор или IDE (например, Qt Creator) и создайте свое приложение или загрузите пример Qt. Затем выполните qmake и nmake/jom, чтобы собрать ваше приложение.

Сборка приложений с помощью Visual Studio

Чтобы запустить свой проект с Visual Studio, необходимо создать соответствующий проект. qmake поддерживает преобразование проекта .pro в формат Visual Studio, передавая параметры -tp vc.

qmake -tp vc <your project>.pro

Следите за правильным соответствием qmake и Visual Studio. Поскольку формат Visual Studio является общим, он не возвращает немедленную ошибку, если, например, вы откроете проект Windows Phone в Visual Studio для Windows.

Это создает проект, который поддерживает сборку приложений и их запуск с помощью Visual Studio. Он не встраивает библиотеки Qt в пакет и требует ручного добавления. Для этой цели в установленный пакет включен инструмент командной строки windeployqt. Чтобы включить автоматическое разбор зависимостей и добавление библиотек и зависимостей в пакет приложения, создайте проект со следующими параметрами:

qmake -tp vc <your project>.pro "CONFIG+=windeployqt"

Сборка приложений с помощью Qt Creator

Вам не нужно выполнять преобразование, чтобы открыть свой проект в Qt Creator. Следуйте общим инструкциям по открытию и сборке проекта.

Qt Creator развертывает ваше приложение на устройстве WinRT, если устройство обнаружено ПК.

Примечание: Удаленные компьютеры, такие как Surface, пока не поддерживаются для развертывания через Creator.

Сборка из исходного кода

Предполагается, что вы клонировали репозитории Qt 5 (или получили исходные коды Qt где-либо еще) и выполнили требования к сборке Qt, независимые от платформы. Процесс сборки Qt описан на странице Сборка исходного кода Qt.

Qt для WinRT всегда собирается как кросс-сборка, потому что такие инструменты, как qmake, собираются как приложения для рабочего стола. Для их компиляции требуется среда разработки для рабочего стола. Если вы установили Visual Studio 2013 для Windows, это создаст только двоичные файлы для WinRT. Вам также потребуется Visual Studio для Windows Desktop, чтобы создать эти инструменты для рабочего стола.

Убедитесь, что вы используете командную строку x86 (либо используйте VS x86 Native Tools Command Prompt, либо вызовите vcvarsall.bat без параметров или с параметром x86) для каждой сборки WinRT. Хотя среда разработки, используемая для целевой платформы, устанавливается автоматически, командная строка определяет, что будет использоваться для инструментов хоста, таких как qmake или moc. Сборка этих инструментов может завершиться сбоем, если используется другая командная строка.

Формат mkspec для WinRT — <platform>-<architecture>-<toolchain>, где архитектура может быть arm, x86, или x64. Ниже приведен пример сборки qtbase для WinRT:

> ./configure -xplatform winrt-x64-msvc2013 -release
> nmake/jom

Запуск приложений из командной строки

Приложения WinRT должны быть упакованы (включая все зависимости) и установлены или зарегистрированы в службе приложений, чтобы их можно было запустить. Инструмент WinRT Runner Tool можно использовать для запуска этих приложений из командной строки.

Содержимое пакета

Содержимое пакета состоит из исполняемого файла приложения и его зависимостей, как и для любого приложения Windows. Зависимости — это необходимые (Qt) библиотеки и плагины. Обратите внимание, что плагины Qt должны помещаться в папку, названную по их категории (платформы, форматы изображений и так далее), без использования папки plugins в качестве корня. Дополнительную информацию см. в разделе Qt для Windows — Развертывание.

Поскольку приложения WinRT выполняются в защищенной среде, установка переменной пути для указания на необходимые файлы не сработает.

Удобный инструмент windeployqt находит зависимости приложения и копирует библиотеки и плагины Qt в соответствующие каталоги по мере необходимости.

Поскольку все ресурсы размещаются в одном каталоге, вы можете зарегистрировать каталог с помощью файла XML (AppxManifest.xml) и Windows PowerShell. Справочник по этим файлам-манифестам можно найти здесь. Необходимо указать целевую архитектуру процессора (в отличие от значения по умолчанию «нейтральная»). Как только эти требования будут выполнены, перейдите в свою папку packaged в PowerShell и вызовите:

> Add-AppxPackage -Register AppxManifest.xml

Примечание: Инструмент WinRT Runner Tool может выполнить ту же операцию с параметром --install.

Если все прошло успешно, вы должны увидеть свое приложение на начальном экране Windows. Чтобы удалить приложение, используйте встроенный в Windows способ удаления приложений (щелкните правой кнопкой мыши или удерживайте палец на приложении и выберите Uninstall).

Примечание: Инструмент WinRT Runner Tool может выполнить ту же операцию с параметром --remove.

Инструмент WinRT Runner

Инструмент WinRT Runner находится в QTDIR/bin/winrtrunner. Он предназначен для помощи в развертывании, запуске и отладке приложений Qt для WinRT. Его можно использовать из командной строки или вызвать из IDE.

Usage: winrtrunner [options] package [arguments]
winrtrunner installs, runs, and collects test results for packages made with Qt.

Options:
  --test                            Install, start, collect output, stop (if
                                    needed), and uninstall the package. This is
                                    the default action of winrtrunner.
  --start                           Start the package. The package is installed
                                    if it is not already installed. Pass
                                    --install to force reinstallation.
  --debug <debugger>                Start the package with the debugger
                                    attached. The package is installed if it is
                                    not already installed. Pass --install to
                                    force reinstallation.
  --debugger-arguments <arguments>  Arguments that are passed to the debugger
                                    when --debug is used. If no debugger was
                                    provided this option is ignored.
  --suspend                         Suspend a running package. When combined
                                    with --stop or --test, the app will be
                                    suspended before being terminated.
  --stop                            Terminate a running package. Can be be
                                    combined with --start and --suspend.
  --wait <seconds>                  If the package is running, waits the given
                                    number of seconds before continuing to the
                                    next task. Passing 0 causes the runner to
                                    wait indefinitely.
  --install                         (Re)installs the package.
  --remove                          Uninstalls the package.
  --device <name|index>             Specifies the device to target as a device
                                    name or index. Use --list-devices to find
                                    available devices. The default device is the
                                    first device found for the active run
                                    profile.
  --profile <name>                  Force a particular run profile.
  --list-devices                    List the available devices (for use with
                                    --device).
  --verbose <level>                 The verbosity level of the message output
                                    (0 - silent, 1 - info, 2 - debug). Defaults
                                    to 1.
  --ignore-errors                   Always exit with code 0, regardless of the
                                    error state.
  --loopbackexempt <mode>           Enables localhost communication for
                                    clients,servers or both. Adding this
                                    possibility for servers needs elevated
                                    rights and might ask for these in a
                                    dialog.Possible values: client, server,
                                    clientserver
  -?, -h, --help                    Displays this help.

Arguments:
  package [arguments]               The executable or package manifest to act
                                    upon. Arguments after the package name will
                                    be passed to the application when it starts.

© The Qt Company Ltd
Licensed under the GNU Free Documentation License, Version 1.3.
https://doc.qt.io/qt-5.12/winrt-support.html

Spec-Zone.ru

Настройки Оффлайн Что нового Помощь О нас
Spec-Zone .ru
спецификации, руководства, описания, API